aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/python/tools/saved_model_cli.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/python/tools/saved_model_cli.py')
-rw-r--r--tensorflow/python/tools/saved_model_cli.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tensorflow/python/tools/saved_model_cli.py b/tensorflow/python/tools/saved_model_cli.py
index e19b187681..e1be305505 100644
--- a/tensorflow/python/tools/saved_model_cli.py
+++ b/tensorflow/python/tools/saved_model_cli.py
@@ -489,7 +489,7 @@ def show(args):
else:
# If no tag is specified, display all tag_set, if no signaure_def key is
# specified, display all SignatureDef keys, else show input output tensor
# infomation corresponding to the given SignatureDef key
if args.tag_set is None:
_show_tag_sets(args.dir)
else:
@@ -562,7 +562,7 @@ def create_parser():
parser_show.add_argument(
'--all',
action='store_true',
- help='if set, will output all infomation in given SavedModel')
+ help='if set, will output all information in given SavedModel')
parser_show.add_argument(
'--tag_set',
type=str,
@@ -489,7 +489,7 @@ def show(args):
# If no tag is specified, display all tag_set, if no signaure_def key is
# specified, display all SignatureDef keys, else show input output tensor
- # infomation corresponding to the given SignatureDef key
+ # information corresponding to the given SignatureDef key
if args.tag_set is None:
_show_tag_sets(args.dir)